@@ -5,7 +5,7 @@ from dataclasses import dataclass
 from typing import TYPE_CHECKING, ClassVar, Iterable
 
 from rich.cells import cell_len, get_character_cell_size
-from rich.console import Console, ConsoleOptions
+from rich.console import Console, ConsoleOptions, RenderableType
 from rich.console import RenderResult as RichRenderResult
 from rich.highlighter import Highlighter
 from rich.segment import Segment
@@ -23,7 +23,7 @@ from ..css._error_tools import friendly_list
 from ..events import Blur, Focus, Mount
 from ..geometry import Offset, Size
 from ..message import Message
-from ..reactive import reactive, var
+from ..reactive import Reactive, reactive, var
 from ..suggester import Suggester, SuggestionReady
 from ..timer import Timer
 from ..validation import ValidationResult, Validator
@@ -174,7 +174,7 @@ class Input(Widget, can_focus=True):
     cursor_blink = reactive(True, init=False)
     value = reactive("", layout=True, init=False)
     input_scroll_offset = reactive(0)
-    cursor_position = reactive(0)
+    cursor_position: Reactive[int] = reactive(0)
     view_position = reactive(0)
     placeholder = reactive("")
     complete = reactive("")
@@ -257,6 +257,7 @@ class Input(Widget, can_focus=True):
         id: str | None = None,
         classes: str | None = None,
         disabled: bool = False,
+        tooltip: RenderableType | None = None,
     ) -> None:
         """Initialise the `Input` widget.
 
@@ -279,6 +280,7 @@ class Input(Widget, can_focus=True):
             id: Optional ID for the widget.
             classes: Optional initial classes for the widget.
             disabled: Whether the input is disabled or not.
+            tooltip: Optional tooltip.
         """
         super().__init__(name=name, id=id, classes=classes, disabled=disabled)
 
@@ -298,8 +300,8 @@ class Input(Widget, can_focus=True):
         else:
             self.validators = list(validators)
 
-        self.validate_on = (
-            set(validate_on) & _POSSIBLE_VALIDATE_ON_VALUES
+        self.validate_on: set[str] = (
+            (_POSSIBLE_VALIDATE_ON_VALUES & set(validate_on))
             if validate_on is not None
             else _POSSIBLE_VALIDATE_ON_VALUES
         )
@@ -333,9 +335,14 @@ class Input(Widget, can_focus=True):
             elif self.type == "number":
                 self.validators.append(Number())
 
+        self._initial_value = True
+        """Indicates if the value has been set for the first time yet."""
         if value is not None:
             self.value = value
 
+        if tooltip is not None:
+            self.tooltip = tooltip
+
     def _position_to_cell(self, position: int) -> int:
         """Convert an index within the value to cell position."""
         cell_offset = cell_len(self.value[:position])
@@ -387,8 +394,8 @@ class Input(Widget, can_focus=True):
             if blink:
                 self._blink_timer.resume()
             else:
+                self._pause_blink_cycle()
                 self._cursor_visible = True
-                self._blink_timer.pause()
 
     @property
     def cursor_screen_offset(self) -> Offset:
@@ -408,6 +415,11 @@ class Input(Widget, can_focus=True):
         )
         self.post_message(self.Changed(self, value, validation_result))
 
+        # If this is the first time the value has been updated, set the cursor position to the end
+        if self._initial_value:
+            self.cursor_position = len(self.value)
+            self._initial_value = False
+
     def _watch_valid_empty(self) -> None:
         """Repeat validation when valid_empty changes."""
         self._watch_value(self.value)
@@ -502,29 +514,25 @@ class Input(Widget, can_focus=True):
         """Toggle visibility of cursor."""
         self._cursor_visible = not self._cursor_visible
 
-    def _on_mount(self, _: Mount) -> None:
+    def _on_mount(self, event: Mount) -> None:
         self._blink_timer = self.set_interval(
             0.5,
             self._toggle_cursor,
             pause=not (self.cursor_blink and self.has_focus),
         )
 
-    def _on_blur(self, _: Blur) -> None:
-        self._blink_timer.pause()
+    def _on_blur(self, event: Blur) -> None:
+        self._pause_blink_cycle()
         if "blur" in self.validate_on:
             self.validate(self.value)
 
-    def _on_focus(self, _: Focus) -> None:
-        self.cursor_position = len(self.value)
-        if self.cursor_blink:
-            self._blink_timer.resume()
+    def _on_focus(self, event: Focus) -> None:
+        self._restart_blink_cycle()
         self.app.cursor_position = self.cursor_screen_offset
         self._suggestion = ""
 
     async def _on_key(self, event: events.Key) -> None:
-        self._cursor_visible = True
-        if self.cursor_blink:
-            self._blink_timer.reset()
+        self._restart_blink_cycle()
 
         if event.is_printable:
             event.stop()
@@ -555,11 +563,29 @@ class Input(Widget, can_focus=True):
         else:
             self.cursor_position = len(self.value)
 
+    async def _on_mouse_down(self, event: events.MouseDown) -> None:
+        self._pause_blink_cycle()
+
+    async def _on_mouse_up(self, event: events.MouseUp) -> None:
+        self._restart_blink_cycle()
+
     async def _on_suggestion_ready(self, event: SuggestionReady) -> None:
         """Handle suggestion messages and set the suggestion when relevant."""
         if event.value == self.value:
             self._suggestion = event.suggestion
 
+    def _restart_blink_cycle(self) -> None:
+        """Restart the cursor blink cycle."""
+        self._cursor_visible = True
+        if self.cursor_blink and self._blink_timer:
+            self._blink_timer.reset()
+
+    def _pause_blink_cycle(self) -> None:
+        """Hide the blinking cursor and pause the blink cycle."""
+        self._cursor_visible = False
+        if self._blink_timer:
+            self._blink_timer.pause()
+
     def insert_text_at_cursor(self, text: str) -> None:
         """Insert new text at the cursor, move the cursor to the end of the new text.
 
@@ -732,7 +758,8 @@ class Input(Widget, can_focus=True):
                 self.cursor_position = 0
             else:
                 self.cursor_position = hit.start()
-            self.value = f"{self.value[: self.cursor_position]}{after}"
+            new_value = f"{self.value[: self.cursor_position]}{after}"
+            self.value = new_value
 
     def action_delete_left_all(self) -> None:
         """Delete all characters to the left of the cursor position."""
